%% Swiss Rectifier Parameters:
SR.L = 305e-6; % [H] - Output inductances
SR.Lr= 0.1; % [Ohm] - Inductor resistance
SR.C = 470e-6; % [C] - Output capacitance
SR.R = 2*450^2/5000; % [Ohm] - Output resistance
SR.fs = 28000; % [Hz] - Switching frequency
SR.Ts = 1/SR.fs; % [s] - Switching period
SR.Vamp = 325; % [V] - Peak voltage amplitude
SR.Vfreq = 50; % [Hz] - Three phase voltage frequency


% LC filter design
SR.Cf = 6.8e-6; % [F]
SR.Lf = 245e-6; % [H]
SR.Lfd = 130e-6; % [H]
SR.Rd = 2.15; % [Ohm]

%% Current Controls

% Small time constants
CC.PWM = 0.5*SR.Ts; % [s] - PWM modulator small time constant
CC.Tcs = 1/(2*pi*(10*SR.fs)); % [s] - Current sensor small time constant
CC.f_samp = SR.fs; % [Hz] - Sampling frequency
CC.Tsp = 1/CC.f_samp; % [s] - Sampling small time constant
CC.Tpe = CC.PWM + CC.Tcs + CC.Tsp; % [s] - Equivalent small time constant

% Dominant time constants
CC.Tn=2*SR.L/(2*SR.Lr);
CC.Ti=2*CC.Tpe;

% Controller
CC.Kp=CC.Tn/CC.Ti;
CC.Ki=1/CC.Ti;
CC.Tp_current=2*sqrt(CC.Ti*CC.Tpe);
CC.K_aw=1/CC.Kp;

CC.upper=1.5*SR.Vamp;
CC.lower=0;

%% Voltage controller
VC.Tp_Vloop = CC.Tsp*2; %CC.Tp_current/2;
VC.Tsp=VC.Tp_Vloop;
VC.Ti_Vloop = 8/SR.C*VC.Tp_Vloop*VC.Tp_Vloop;
VC.Tn_Vloop = 4*VC.Tp_Vloop;

VC.Kp = VC.Tn_Vloop/VC.Ti_Vloop;
VC.Ki = 1/VC.Ti_Vloop;
VC.K_aw=1/VC.Kp;
VC.upper=25;
VC.lower=0;